@@ -38,9 +38,23 @@ test_that("geom lines work", {
     scale_x_reverse() +
     theme_minimal()
 
+  # It seems like vdiffr isn't handling cran = FALSE properly so I call
+  # skip_on_cran() explicitly
+  skip_on_cran()
   vdiffr::expect_doppelganger("p1", p1)
   vdiffr::expect_doppelganger("p2", p2)
   vdiffr::expect_doppelganger("p3", p3)
   vdiffr::expect_doppelganger("p4", p4)
   vdiffr::expect_doppelganger("p5", p5)
+
+  if(is_ggplot_340()){
+    # deprecated size aesthetic warning
+    p6 <- ggplot(mtcars, aes(x = disp, y = mpg, y0 = mpg, x0 = disp)) +
+      geom_point() +
+      geom_median_lines(size = 2) +
+      geom_mean_lines(color = "blue") +
+      theme_minimal()
+
+    expect_warning(print(p6), "The `size` aesthetic has been deprecated")
+  }
 })
